==> haskell-http-common-0.8.2.0-50-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-common
version: 0.8.2.0
id: http-common-0.8.2.0-9lSqEtwEInD8IWm2CUQC66
key: http-common-0.8.2.0-9lSqEtwEInD8IWm2CUQC66
license: BSD-3-Clause
copyright: © 2012-2015 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: http://research.operationaldynamics.com/projects/http-streams/
synopsis: Common types for HTTP clients and servers
description:
    /Overview/
    .
    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.
category: Web
abi: d9202b8ba1c6181d5778bf2e48e9377b
exposed: True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-common-0.8.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-common-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-common-0.8.2.0
hs-libraries: HShttp-common-0.8.2.0-9lSqEtwEInD8IWm2CUQC66
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-Bm9gqw70QXoBbkNHszCarm
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk directory-1.3.3.0
    mtl-2.2.2 network-2.8.0.0-EWiez0ajBalJ2cORFP4yEt text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-2N7l4ZvxBr3HGayD0s0P1Q
haddock-interfaces: /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html: /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-common-0.8.2.0-51-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-common
version: 0.8.2.0
id: http-common-0.8.2.0-GHnl69BLqK3LEWb2TYsshZ
key: http-common-0.8.2.0-GHnl69BLqK3LEWb2TYsshZ
license: BSD-3-Clause
copyright: © 2012-2015 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: http://research.operationaldynamics.com/projects/http-streams/
synopsis: Common types for HTTP clients and servers
description:
    /Overview/
    .
    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.
category: Web
abi: 148bda3666ab3fe83dd56d77a2b9e446
exposed: True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-common-0.8.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-common-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-common-0.8.2.0
hs-libraries: HShttp-common-0.8.2.0-GHnl69BLqK3LEWb2TYsshZ
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-Exy4D7U0AzaE8TUydrgSTP
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk directory-1.3.3.0
    mtl-2.2.2 network-2.8.0.0-KwUidTBebCCJ8Fjkxwovi text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-FCaPs5fnhYpFgvItTiMoQE
haddock-interfaces: /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html: /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
